==> haskell-ghc-check-0.5.0.8-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-ACOX2h7CVveCbYKeqWP36F
key:                  ghc-check-0.5.0.8-ACOX2h7CVveCbYKeqWP36F
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  5b9b511531008a9af6a6b8b928aa9a97
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-ACOX2h7CVveCbYKeqWP36F
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    process-1.6.18.0 safe-exceptions-0.1.7.4-2aYxNbFpmMwKpdUZnREf2B
    template-haskell-2.19.0.0 th-compat-0.1.5-GkQyEWlPQAXGEL1Xk7Or1D
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-check-0.5.0.8-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-EU555qQ9J2M4VHAJBTMdI5
key:                  ghc-check-0.5.0.8-EU555qQ9J2M4VHAJBTMdI5
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  ca9a35d193064cb091f399ef119042a6
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-EU555qQ9J2M4VHAJBTMdI5
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    process-1.6.18.0 safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M
    template-haskell-2.19.0.0 th-compat-0.1.5-DGDHQ3zg5lpAWsPNoCEdRG
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
